generic-report-generator-psql 
===========================
Implementation of [generic-report-generator](https://github.com/davidNHK/generic-report-generator) for postgresql

Table of contents
=================
  * [Installation](#installation)
  * [Development](#development)
  * [Testing](#testing)

Installation
============

```bash
pip3 install generic-report-generator-psql
```

Development
===========

```bash
pipenv install
```

Testing
=======

```bash
bash ./scripts/test
```